# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.24.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_gitea_opensuse_org.models.action_workflow_response import ActionWorkflowResponse

class TestActionWorkflowResponse(unittest.TestCase):
    """ActionWorkflowResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ActionWorkflowResponse:
        """Test ActionWorkflowResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ActionWorkflowResponse`
        """
        model = ActionWorkflowResponse()
        if include_optional:
            return ActionWorkflowResponse(
                total_count = 56,
                workflows = [
                    py_gitea_opensuse_org.models.action_workflow.ActionWorkflow(
                        badge_url = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        deleted_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        html_url = '', 
                        id = '', 
                        name = '', 
                        path = '', 
                        state = '', 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        url = '', )
                    ]
            )
        else:
            return ActionWorkflowResponse(
        )
        """

    def testActionWorkflowResponse(self):
        """Test ActionWorkflowResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
