# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.24.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_gitea_opensuse_org.models.action_artifacts_response import ActionArtifactsResponse

class TestActionArtifactsResponse(unittest.TestCase):
    """ActionArtifactsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ActionArtifactsResponse:
        """Test ActionArtifactsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ActionArtifactsResponse`
        """
        model = ActionArtifactsResponse()
        if include_optional:
            return ActionArtifactsResponse(
                artifacts = [
                    py_gitea_opensuse_org.models.action_artifact.ActionArtifact(
                        archive_download_url = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expired = True, 
                        expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = 56, 
                        name = '', 
                        size_in_bytes = 56, 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        url = '', 
                        workflow_run = py_gitea_opensuse_org.models.action_workflow_run.ActionWorkflowRun(
                            head_sha = '', 
                            id = 56, 
                            repository_id = 56, ), )
                    ],
                total_count = 56
            )
        else:
            return ActionArtifactsResponse(
        )
        """

    def testActionArtifactsResponse(self):
        """Test ActionArtifactsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
