# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.21.0-rc1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from py_gitea_opensuse_org.models.change_file_operation import ChangeFileOperation


class TestChangeFileOperation(unittest.TestCase):
    """ChangeFileOperation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChangeFileOperation:
        """Test ChangeFileOperation
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `ChangeFileOperation`
        """
        model = ChangeFileOperation()
        if include_optional:
            return ChangeFileOperation(
                content = '',
                from_path = '',
                operation = 'create',
                path = '',
                sha = ''
            )
        else:
            return ChangeFileOperation(
                operation = 'create',
                path = '',
        )
        """

    def testChangeFileOperation(self):
        """Test ChangeFileOperation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
