# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.  # noqa: E501

    The version of the OpenAPI document: 1.19.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import py_gitea_opensuse_org
from py_gitea_opensuse_org.api.activitypub_api import ActivitypubApi  # noqa: E501
from py_gitea_opensuse_org.rest import ApiException


class TestActivitypubApi(unittest.TestCase):
    """ActivitypubApi unit test stubs"""

    def setUp(self):
        self.api = (
            py_gitea_opensuse_org.api.activitypub_api.ActivitypubApi()
        )  # noqa: E501

    def tearDown(self):
        pass

    def test_activitypub_person(self):
        """Test case for activitypub_person

        Returns the Person actor for a user  # noqa: E501
        """
        pass

    def test_activitypub_person_inbox(self):
        """Test case for activitypub_person_inbox

        Send to the inbox  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
