# coding: utf-8

# flake8: noqa

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.24.4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.24.4"

# Define package exports
__all__ = [
    "ActivitypubApi",
    "AdminApi",
    "IssueApi",
    "MiscellaneousApi",
    "NotificationApi",
    "OrganizationApi",
    "PackageApi",
    "RepositoryApi",
    "SettingsApi",
    "UserApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "APIError",
    "AccessToken",
    "ActionArtifact",
    "ActionArtifactsResponse",
    "ActionRunner",
    "ActionRunnerLabel",
    "ActionRunnersResponse",
    "ActionTask",
    "ActionTaskResponse",
    "ActionVariable",
    "ActionWorkflow",
    "ActionWorkflowResponse",
    "ActionWorkflowRun",
    "Activity",
    "ActivityPub",
    "AddCollaboratorOption",
    "AddTimeOption",
    "AnnotatedTag",
    "AnnotatedTagObject",
    "Attachment",
    "Badge",
    "Branch",
    "BranchProtection",
    "ChangeFileOperation",
    "ChangeFilesOptions",
    "ChangedFile",
    "CombinedStatus",
    "Comment",
    "Commit",
    "CommitAffectedFiles",
    "CommitDateOptions",
    "CommitMeta",
    "CommitStats",
    "CommitStatus",
    "CommitUser",
    "Compare",
    "ContentsResponse",
    "CreateAccessTokenOption",
    "CreateActionWorkflowDispatch",
    "CreateBranchProtectionOption",
    "CreateBranchRepoOption",
    "CreateEmailOption",
    "CreateFileOptions",
    "CreateForkOption",
    "CreateGPGKeyOption",
    "CreateHookOption",
    "CreateIssueCommentOption",
    "CreateIssueOption",
    "CreateKeyOption",
    "CreateLabelOption",
    "CreateMilestoneOption",
    "CreateOAuth2ApplicationOptions",
    "CreateOrUpdateSecretOption",
    "CreateOrgOption",
    "CreatePullRequestOption",
    "CreatePullReviewComment",
    "CreatePullReviewOptions",
    "CreatePushMirrorOption",
    "CreateReleaseOption",
    "CreateRepoOption",
    "CreateStatusOption",
    "CreateTagOption",
    "CreateTagProtectionOption",
    "CreateTeamOption",
    "CreateUserOption",
    "CreateVariableOption",
    "CreateWikiPageOptions",
    "Cron",
    "DeleteEmailOption",
    "DeleteFileOptions",
    "DeployKey",
    "DismissPullReviewOptions",
    "EditAttachmentOptions",
    "EditBranchProtectionOption",
    "EditDeadlineOption",
    "EditGitHookOption",
    "EditHookOption",
    "EditIssueCommentOption",
    "EditIssueOption",
    "EditLabelOption",
    "EditMilestoneOption",
    "EditOrgOption",
    "EditPullRequestOption",
    "EditReactionOption",
    "EditReleaseOption",
    "EditRepoOption",
    "EditTagProtectionOption",
    "EditTeamOption",
    "EditUserOption",
    "Email",
    "ExternalTracker",
    "ExternalWiki",
    "FileCommitResponse",
    "FileDeleteResponse",
    "FileLinksResponse",
    "FileResponse",
    "FilesResponse",
    "GPGKey",
    "GPGKeyEmail",
    "GeneralAPISettings",
    "GeneralAttachmentSettings",
    "GeneralRepoSettings",
    "GeneralUISettings",
    "GenerateRepoOption",
    "GetFilesOptions",
    "GitBlobResponse",
    "GitEntry",
    "GitHook",
    "GitObject",
    "GitTreeResponse",
    "GitignoreTemplateInfo",
    "Hook",
    "Identity",
    "InternalTracker",
    "Issue",
    "IssueConfig",
    "IssueConfigContactLink",
    "IssueConfigValidation",
    "IssueDeadline",
    "IssueFormField",
    "IssueLabelsOption",
    "IssueMeta",
    "IssueTemplate",
    "Label",
    "LabelTemplate",
    "LicenseTemplateInfo",
    "LicensesTemplateListEntry",
    "LockIssueOption",
    "MarkdownOption",
    "MarkupOption",
    "MergePullRequestOption",
    "MergeUpstreamRequest",
    "MergeUpstreamResponse",
    "MigrateRepoOptions",
    "Milestone",
    "NewIssuePinsAllowed",
    "NodeInfo",
    "NodeInfoServices",
    "NodeInfoSoftware",
    "NodeInfoUsage",
    "NodeInfoUsageUsers",
    "Note",
    "NotificationCount",
    "NotificationSubject",
    "NotificationThread",
    "OAuth2Application",
    "Organization",
    "OrganizationPermissions",
    "PRBranchInfo",
    "Package",
    "PackageFile",
    "PayloadCommit",
    "PayloadCommitVerification",
    "PayloadUser",
    "Permission",
    "PublicKey",
    "PullRequest",
    "PullRequestMeta",
    "PullReview",
    "PullReviewComment",
    "PullReviewRequestOptions",
    "PushMirror",
    "Reaction",
    "Reference",
    "Release",
    "RenameOrgOption",
    "RenameUserOption",
    "RepoCollaboratorPermission",
    "RepoCommit",
    "RepoCreateReleaseAttachmentRequest",
    "RepoTopicOptions",
    "RepoTransfer",
    "Repository",
    "RepositoryMeta",
    "SearchResults",
    "Secret",
    "ServerVersion",
    "StopWatch",
    "SubmitPullReviewOptions",
    "Tag",
    "TagProtection",
    "Team",
    "TeamSearch200Response",
    "TimelineComment",
    "TopicName",
    "TopicResponse",
    "TrackedTime",
    "TransferRepoOption",
    "UpdateBranchProtectionPriories",
    "UpdateBranchRepoOption",
    "UpdateFileOptions",
    "UpdateRepoAvatarOption",
    "UpdateUserAvatarOption",
    "UpdateVariableOption",
    "User",
    "UserBadgeOption",
    "UserHeatmapData",
    "UserSearch200Response",
    "UserSettings",
    "UserSettingsOptions",
    "WatchInfo",
    "WikiCommit",
    "WikiCommitList",
    "WikiPage",
    "WikiPageMetaData",
]

# import apis into sdk package
from py_gitea_opensuse_org.api.activitypub_api import ActivitypubApi as ActivitypubApi
from py_gitea_opensuse_org.api.admin_api import AdminApi as AdminApi
from py_gitea_opensuse_org.api.issue_api import IssueApi as IssueApi
from py_gitea_opensuse_org.api.miscellaneous_api import MiscellaneousApi as MiscellaneousApi
from py_gitea_opensuse_org.api.notification_api import NotificationApi as NotificationApi
from py_gitea_opensuse_org.api.organization_api import OrganizationApi as OrganizationApi
from py_gitea_opensuse_org.api.package_api import PackageApi as PackageApi
from py_gitea_opensuse_org.api.repository_api import RepositoryApi as RepositoryApi
from py_gitea_opensuse_org.api.settings_api import SettingsApi as SettingsApi
from py_gitea_opensuse_org.api.user_api import UserApi as UserApi

# import ApiClient
from py_gitea_opensuse_org.api_response import ApiResponse as ApiResponse
from py_gitea_opensuse_org.api_client import ApiClient as ApiClient
from py_gitea_opensuse_org.configuration import Configuration as Configuration
from py_gitea_opensuse_org.exceptions import OpenApiException as OpenApiException
from py_gitea_opensuse_org.exceptions import ApiTypeError as ApiTypeError
from py_gitea_opensuse_org.exceptions import ApiValueError as ApiValueError
from py_gitea_opensuse_org.exceptions import ApiKeyError as ApiKeyError
from py_gitea_opensuse_org.exceptions import ApiAttributeError as ApiAttributeError
from py_gitea_opensuse_org.exceptions import ApiException as ApiException

# import models into sdk package
from py_gitea_opensuse_org.models.api_error import APIError as APIError
from py_gitea_opensuse_org.models.access_token import AccessToken as AccessToken
from py_gitea_opensuse_org.models.action_artifact import ActionArtifact as ActionArtifact
from py_gitea_opensuse_org.models.action_artifacts_response import ActionArtifactsResponse as ActionArtifactsResponse
from py_gitea_opensuse_org.models.action_runner import ActionRunner as ActionRunner
from py_gitea_opensuse_org.models.action_runner_label import ActionRunnerLabel as ActionRunnerLabel
from py_gitea_opensuse_org.models.action_runners_response import ActionRunnersResponse as ActionRunnersResponse
from py_gitea_opensuse_org.models.action_task import ActionTask as ActionTask
from py_gitea_opensuse_org.models.action_task_response import ActionTaskResponse as ActionTaskResponse
from py_gitea_opensuse_org.models.action_variable import ActionVariable as ActionVariable
from py_gitea_opensuse_org.models.action_workflow import ActionWorkflow as ActionWorkflow
from py_gitea_opensuse_org.models.action_workflow_response import ActionWorkflowResponse as ActionWorkflowResponse
from py_gitea_opensuse_org.models.action_workflow_run import ActionWorkflowRun as ActionWorkflowRun
from py_gitea_opensuse_org.models.activity import Activity as Activity
from py_gitea_opensuse_org.models.activity_pub import ActivityPub as ActivityPub
from py_gitea_opensuse_org.models.add_collaborator_option import AddCollaboratorOption as AddCollaboratorOption
from py_gitea_opensuse_org.models.add_time_option import AddTimeOption as AddTimeOption
from py_gitea_opensuse_org.models.annotated_tag import AnnotatedTag as AnnotatedTag
from py_gitea_opensuse_org.models.annotated_tag_object import AnnotatedTagObject as AnnotatedTagObject
from py_gitea_opensuse_org.models.attachment import Attachment as Attachment
from py_gitea_opensuse_org.models.badge import Badge as Badge
from py_gitea_opensuse_org.models.branch import Branch as Branch
from py_gitea_opensuse_org.models.branch_protection import BranchProtection as BranchProtection
from py_gitea_opensuse_org.models.change_file_operation import ChangeFileOperation as ChangeFileOperation
from py_gitea_opensuse_org.models.change_files_options import ChangeFilesOptions as ChangeFilesOptions
from py_gitea_opensuse_org.models.changed_file import ChangedFile as ChangedFile
from py_gitea_opensuse_org.models.combined_status import CombinedStatus as CombinedStatus
from py_gitea_opensuse_org.models.comment import Comment as Comment
from py_gitea_opensuse_org.models.commit import Commit as Commit
from py_gitea_opensuse_org.models.commit_affected_files import CommitAffectedFiles as CommitAffectedFiles
from py_gitea_opensuse_org.models.commit_date_options import CommitDateOptions as CommitDateOptions
from py_gitea_opensuse_org.models.commit_meta import CommitMeta as CommitMeta
from py_gitea_opensuse_org.models.commit_stats import CommitStats as CommitStats
from py_gitea_opensuse_org.models.commit_status import CommitStatus as CommitStatus
from py_gitea_opensuse_org.models.commit_user import CommitUser as CommitUser
from py_gitea_opensuse_org.models.compare import Compare as Compare
from py_gitea_opensuse_org.models.contents_response import ContentsResponse as ContentsResponse
from py_gitea_opensuse_org.models.create_access_token_option import CreateAccessTokenOption as CreateAccessTokenOption
from py_gitea_opensuse_org.models.create_action_workflow_dispatch import CreateActionWorkflowDispatch as CreateActionWorkflowDispatch
from py_gitea_opensuse_org.models.create_branch_protection_option import CreateBranchProtectionOption as CreateBranchProtectionOption
from py_gitea_opensuse_org.models.create_branch_repo_option import CreateBranchRepoOption as CreateBranchRepoOption
from py_gitea_opensuse_org.models.create_email_option import CreateEmailOption as CreateEmailOption
from py_gitea_opensuse_org.models.create_file_options import CreateFileOptions as CreateFileOptions
from py_gitea_opensuse_org.models.create_fork_option import CreateForkOption as CreateForkOption
from py_gitea_opensuse_org.models.create_gpg_key_option import CreateGPGKeyOption as CreateGPGKeyOption
from py_gitea_opensuse_org.models.create_hook_option import CreateHookOption as CreateHookOption
from py_gitea_opensuse_org.models.create_issue_comment_option import CreateIssueCommentOption as CreateIssueCommentOption
from py_gitea_opensuse_org.models.create_issue_option import CreateIssueOption as CreateIssueOption
from py_gitea_opensuse_org.models.create_key_option import CreateKeyOption as CreateKeyOption
from py_gitea_opensuse_org.models.create_label_option import CreateLabelOption as CreateLabelOption
from py_gitea_opensuse_org.models.create_milestone_option import CreateMilestoneOption as CreateMilestoneOption
from py_gitea_opensuse_org.models.create_o_auth2_application_options import CreateOAuth2ApplicationOptions as CreateOAuth2ApplicationOptions
from py_gitea_opensuse_org.models.create_or_update_secret_option import CreateOrUpdateSecretOption as CreateOrUpdateSecretOption
from py_gitea_opensuse_org.models.create_org_option import CreateOrgOption as CreateOrgOption
from py_gitea_opensuse_org.models.create_pull_request_option import CreatePullRequestOption as CreatePullRequestOption
from py_gitea_opensuse_org.models.create_pull_review_comment import CreatePullReviewComment as CreatePullReviewComment
from py_gitea_opensuse_org.models.create_pull_review_options import CreatePullReviewOptions as CreatePullReviewOptions
from py_gitea_opensuse_org.models.create_push_mirror_option import CreatePushMirrorOption as CreatePushMirrorOption
from py_gitea_opensuse_org.models.create_release_option import CreateReleaseOption as CreateReleaseOption
from py_gitea_opensuse_org.models.create_repo_option import CreateRepoOption as CreateRepoOption
from py_gitea_opensuse_org.models.create_status_option import CreateStatusOption as CreateStatusOption
from py_gitea_opensuse_org.models.create_tag_option import CreateTagOption as CreateTagOption
from py_gitea_opensuse_org.models.create_tag_protection_option import CreateTagProtectionOption as CreateTagProtectionOption
from py_gitea_opensuse_org.models.create_team_option import CreateTeamOption as CreateTeamOption
from py_gitea_opensuse_org.models.create_user_option import CreateUserOption as CreateUserOption
from py_gitea_opensuse_org.models.create_variable_option import CreateVariableOption as CreateVariableOption
from py_gitea_opensuse_org.models.create_wiki_page_options import CreateWikiPageOptions as CreateWikiPageOptions
from py_gitea_opensuse_org.models.cron import Cron as Cron
from py_gitea_opensuse_org.models.delete_email_option import DeleteEmailOption as DeleteEmailOption
from py_gitea_opensuse_org.models.delete_file_options import DeleteFileOptions as DeleteFileOptions
from py_gitea_opensuse_org.models.deploy_key import DeployKey as DeployKey
from py_gitea_opensuse_org.models.dismiss_pull_review_options import DismissPullReviewOptions as DismissPullReviewOptions
from py_gitea_opensuse_org.models.edit_attachment_options import EditAttachmentOptions as EditAttachmentOptions
from py_gitea_opensuse_org.models.edit_branch_protection_option import EditBranchProtectionOption as EditBranchProtectionOption
from py_gitea_opensuse_org.models.edit_deadline_option import EditDeadlineOption as EditDeadlineOption
from py_gitea_opensuse_org.models.edit_git_hook_option import EditGitHookOption as EditGitHookOption
from py_gitea_opensuse_org.models.edit_hook_option import EditHookOption as EditHookOption
from py_gitea_opensuse_org.models.edit_issue_comment_option import EditIssueCommentOption as EditIssueCommentOption
from py_gitea_opensuse_org.models.edit_issue_option import EditIssueOption as EditIssueOption
from py_gitea_opensuse_org.models.edit_label_option import EditLabelOption as EditLabelOption
from py_gitea_opensuse_org.models.edit_milestone_option import EditMilestoneOption as EditMilestoneOption
from py_gitea_opensuse_org.models.edit_org_option import EditOrgOption as EditOrgOption
from py_gitea_opensuse_org.models.edit_pull_request_option import EditPullRequestOption as EditPullRequestOption
from py_gitea_opensuse_org.models.edit_reaction_option import EditReactionOption as EditReactionOption
from py_gitea_opensuse_org.models.edit_release_option import EditReleaseOption as EditReleaseOption
from py_gitea_opensuse_org.models.edit_repo_option import EditRepoOption as EditRepoOption
from py_gitea_opensuse_org.models.edit_tag_protection_option import EditTagProtectionOption as EditTagProtectionOption
from py_gitea_opensuse_org.models.edit_team_option import EditTeamOption as EditTeamOption
from py_gitea_opensuse_org.models.edit_user_option import EditUserOption as EditUserOption
from py_gitea_opensuse_org.models.email import Email as Email
from py_gitea_opensuse_org.models.external_tracker import ExternalTracker as ExternalTracker
from py_gitea_opensuse_org.models.external_wiki import ExternalWiki as ExternalWiki
from py_gitea_opensuse_org.models.file_commit_response import FileCommitResponse as FileCommitResponse
from py_gitea_opensuse_org.models.file_delete_response import FileDeleteResponse as FileDeleteResponse
from py_gitea_opensuse_org.models.file_links_response import FileLinksResponse as FileLinksResponse
from py_gitea_opensuse_org.models.file_response import FileResponse as FileResponse
from py_gitea_opensuse_org.models.files_response import FilesResponse as FilesResponse
from py_gitea_opensuse_org.models.gpg_key import GPGKey as GPGKey
from py_gitea_opensuse_org.models.gpg_key_email import GPGKeyEmail as GPGKeyEmail
from py_gitea_opensuse_org.models.general_api_settings import GeneralAPISettings as GeneralAPISettings
from py_gitea_opensuse_org.models.general_attachment_settings import GeneralAttachmentSettings as GeneralAttachmentSettings
from py_gitea_opensuse_org.models.general_repo_settings import GeneralRepoSettings as GeneralRepoSettings
from py_gitea_opensuse_org.models.general_ui_settings import GeneralUISettings as GeneralUISettings
from py_gitea_opensuse_org.models.generate_repo_option import GenerateRepoOption as GenerateRepoOption
from py_gitea_opensuse_org.models.get_files_options import GetFilesOptions as GetFilesOptions
from py_gitea_opensuse_org.models.git_blob_response import GitBlobResponse as GitBlobResponse
from py_gitea_opensuse_org.models.git_entry import GitEntry as GitEntry
from py_gitea_opensuse_org.models.git_hook import GitHook as GitHook
from py_gitea_opensuse_org.models.git_object import GitObject as GitObject
from py_gitea_opensuse_org.models.git_tree_response import GitTreeResponse as GitTreeResponse
from py_gitea_opensuse_org.models.gitignore_template_info import GitignoreTemplateInfo as GitignoreTemplateInfo
from py_gitea_opensuse_org.models.hook import Hook as Hook
from py_gitea_opensuse_org.models.identity import Identity as Identity
from py_gitea_opensuse_org.models.internal_tracker import InternalTracker as InternalTracker
from py_gitea_opensuse_org.models.issue import Issue as Issue
from py_gitea_opensuse_org.models.issue_config import IssueConfig as IssueConfig
from py_gitea_opensuse_org.models.issue_config_contact_link import IssueConfigContactLink as IssueConfigContactLink
from py_gitea_opensuse_org.models.issue_config_validation import IssueConfigValidation as IssueConfigValidation
from py_gitea_opensuse_org.models.issue_deadline import IssueDeadline as IssueDeadline
from py_gitea_opensuse_org.models.issue_form_field import IssueFormField as IssueFormField
from py_gitea_opensuse_org.models.issue_labels_option import IssueLabelsOption as IssueLabelsOption
from py_gitea_opensuse_org.models.issue_meta import IssueMeta as IssueMeta
from py_gitea_opensuse_org.models.issue_template import IssueTemplate as IssueTemplate
from py_gitea_opensuse_org.models.label import Label as Label
from py_gitea_opensuse_org.models.label_template import LabelTemplate as LabelTemplate
from py_gitea_opensuse_org.models.license_template_info import LicenseTemplateInfo as LicenseTemplateInfo
from py_gitea_opensuse_org.models.licenses_template_list_entry import LicensesTemplateListEntry as LicensesTemplateListEntry
from py_gitea_opensuse_org.models.lock_issue_option import LockIssueOption as LockIssueOption
from py_gitea_opensuse_org.models.markdown_option import MarkdownOption as MarkdownOption
from py_gitea_opensuse_org.models.markup_option import MarkupOption as MarkupOption
from py_gitea_opensuse_org.models.merge_pull_request_option import MergePullRequestOption as MergePullRequestOption
from py_gitea_opensuse_org.models.merge_upstream_request import MergeUpstreamRequest as MergeUpstreamRequest
from py_gitea_opensuse_org.models.merge_upstream_response import MergeUpstreamResponse as MergeUpstreamResponse
from py_gitea_opensuse_org.models.migrate_repo_options import MigrateRepoOptions as MigrateRepoOptions
from py_gitea_opensuse_org.models.milestone import Milestone as Milestone
from py_gitea_opensuse_org.models.new_issue_pins_allowed import NewIssuePinsAllowed as NewIssuePinsAllowed
from py_gitea_opensuse_org.models.node_info import NodeInfo as NodeInfo
from py_gitea_opensuse_org.models.node_info_services import NodeInfoServices as NodeInfoServices
from py_gitea_opensuse_org.models.node_info_software import NodeInfoSoftware as NodeInfoSoftware
from py_gitea_opensuse_org.models.node_info_usage import NodeInfoUsage as NodeInfoUsage
from py_gitea_opensuse_org.models.node_info_usage_users import NodeInfoUsageUsers as NodeInfoUsageUsers
from py_gitea_opensuse_org.models.note import Note as Note
from py_gitea_opensuse_org.models.notification_count import NotificationCount as NotificationCount
from py_gitea_opensuse_org.models.notification_subject import NotificationSubject as NotificationSubject
from py_gitea_opensuse_org.models.notification_thread import NotificationThread as NotificationThread
from py_gitea_opensuse_org.models.o_auth2_application import OAuth2Application as OAuth2Application
from py_gitea_opensuse_org.models.organization import Organization as Organization
from py_gitea_opensuse_org.models.organization_permissions import OrganizationPermissions as OrganizationPermissions
from py_gitea_opensuse_org.models.pr_branch_info import PRBranchInfo as PRBranchInfo
from py_gitea_opensuse_org.models.package import Package as Package
from py_gitea_opensuse_org.models.package_file import PackageFile as PackageFile
from py_gitea_opensuse_org.models.payload_commit import PayloadCommit as PayloadCommit
from py_gitea_opensuse_org.models.payload_commit_verification import PayloadCommitVerification as PayloadCommitVerification
from py_gitea_opensuse_org.models.payload_user import PayloadUser as PayloadUser
from py_gitea_opensuse_org.models.permission import Permission as Permission
from py_gitea_opensuse_org.models.public_key import PublicKey as PublicKey
from py_gitea_opensuse_org.models.pull_request import PullRequest as PullRequest
from py_gitea_opensuse_org.models.pull_request_meta import PullRequestMeta as PullRequestMeta
from py_gitea_opensuse_org.models.pull_review import PullReview as PullReview
from py_gitea_opensuse_org.models.pull_review_comment import PullReviewComment as PullReviewComment
from py_gitea_opensuse_org.models.pull_review_request_options import PullReviewRequestOptions as PullReviewRequestOptions
from py_gitea_opensuse_org.models.push_mirror import PushMirror as PushMirror
from py_gitea_opensuse_org.models.reaction import Reaction as Reaction
from py_gitea_opensuse_org.models.reference import Reference as Reference
from py_gitea_opensuse_org.models.release import Release as Release
from py_gitea_opensuse_org.models.rename_org_option import RenameOrgOption as RenameOrgOption
from py_gitea_opensuse_org.models.rename_user_option import RenameUserOption as RenameUserOption
from py_gitea_opensuse_org.models.repo_collaborator_permission import RepoCollaboratorPermission as RepoCollaboratorPermission
from py_gitea_opensuse_org.models.repo_commit import RepoCommit as RepoCommit
from py_gitea_opensuse_org.models.repo_create_release_attachment_request import RepoCreateReleaseAttachmentRequest as RepoCreateReleaseAttachmentRequest
from py_gitea_opensuse_org.models.repo_topic_options import RepoTopicOptions as RepoTopicOptions
from py_gitea_opensuse_org.models.repo_transfer import RepoTransfer as RepoTransfer
from py_gitea_opensuse_org.models.repository import Repository as Repository
from py_gitea_opensuse_org.models.repository_meta import RepositoryMeta as RepositoryMeta
from py_gitea_opensuse_org.models.search_results import SearchResults as SearchResults
from py_gitea_opensuse_org.models.secret import Secret as Secret
from py_gitea_opensuse_org.models.server_version import ServerVersion as ServerVersion
from py_gitea_opensuse_org.models.stop_watch import StopWatch as StopWatch
from py_gitea_opensuse_org.models.submit_pull_review_options import SubmitPullReviewOptions as SubmitPullReviewOptions
from py_gitea_opensuse_org.models.tag import Tag as Tag
from py_gitea_opensuse_org.models.tag_protection import TagProtection as TagProtection
from py_gitea_opensuse_org.models.team import Team as Team
from py_gitea_opensuse_org.models.team_search200_response import TeamSearch200Response as TeamSearch200Response
from py_gitea_opensuse_org.models.timeline_comment import TimelineComment as TimelineComment
from py_gitea_opensuse_org.models.topic_name import TopicName as TopicName
from py_gitea_opensuse_org.models.topic_response import TopicResponse as TopicResponse
from py_gitea_opensuse_org.models.tracked_time import TrackedTime as TrackedTime
from py_gitea_opensuse_org.models.transfer_repo_option import TransferRepoOption as TransferRepoOption
from py_gitea_opensuse_org.models.update_branch_protection_priories import UpdateBranchProtectionPriories as UpdateBranchProtectionPriories
from py_gitea_opensuse_org.models.update_branch_repo_option import UpdateBranchRepoOption as UpdateBranchRepoOption
from py_gitea_opensuse_org.models.update_file_options import UpdateFileOptions as UpdateFileOptions
from py_gitea_opensuse_org.models.update_repo_avatar_option import UpdateRepoAvatarOption as UpdateRepoAvatarOption
from py_gitea_opensuse_org.models.update_user_avatar_option import UpdateUserAvatarOption as UpdateUserAvatarOption
from py_gitea_opensuse_org.models.update_variable_option import UpdateVariableOption as UpdateVariableOption
from py_gitea_opensuse_org.models.user import User as User
from py_gitea_opensuse_org.models.user_badge_option import UserBadgeOption as UserBadgeOption
from py_gitea_opensuse_org.models.user_heatmap_data import UserHeatmapData as UserHeatmapData
from py_gitea_opensuse_org.models.user_search200_response import UserSearch200Response as UserSearch200Response
from py_gitea_opensuse_org.models.user_settings import UserSettings as UserSettings
from py_gitea_opensuse_org.models.user_settings_options import UserSettingsOptions as UserSettingsOptions
from py_gitea_opensuse_org.models.watch_info import WatchInfo as WatchInfo
from py_gitea_opensuse_org.models.wiki_commit import WikiCommit as WikiCommit
from py_gitea_opensuse_org.models.wiki_commit_list import WikiCommitList as WikiCommitList
from py_gitea_opensuse_org.models.wiki_page import WikiPage as WikiPage
from py_gitea_opensuse_org.models.wiki_page_meta_data import WikiPageMetaData as WikiPageMetaData
